public with sharing class TestSigningUrl {
	public void testSigningUrl(){
		System.debug('signing url: '+new TestSigningUrl().getSigningUrl('ZABQrbJU4usxnGbbd4s5u4Aq8fY=','29d410ca-a16f-4855-925e-d8c24f25a9ff'));
	}
	
    public String getSigningUrl(String packageId, String roleId){
    	String resourceUrl = '/packages/'+packageId+'/roles/'+roleId+'/signingUrl';
        HttpResponse response = doGet(resourceUrl);
		
        // Check response
        if(response.getStatusCode() == 200){
        	try
            {
            	Map<String,Object> responseObject = (Map<String,Object>)JSON.deserializeUntyped(response.getBody());
            	return  (String)responseObject.get('url');
            }
            catch(Exception e)
            {
                throw new ESignLiveRESTAPIHelper.ESignLiveRestAPIHelperException('Error converting signer url json ' + e.getMessage());
            }
        }else{
            throw new ESignLiveRESTAPIHelper.ESignLiveRestAPIHelperException('Error get Signing Url ' + response.getStatusCode() + ' - ' + response.getStatus() + ' - ' +  response.getBody());
        }
    	
    }
    
  private HttpResponse doGet(String resourceUrl){
        e_SignLive_Connection_Settings__c connectionSettings = e_SignLive_Connection_Settings__c.getInstance('Main');    
         // Build Request
        HttpRequest request = new HttpRequest();
        request.setEndpoint(connectionSettings.Endpoint__c + resourceUrl);
        request.setMethod('GET');
        request.setHeader('Authorization', 'Basic ' + connectionSettings.API_Key__c);
        request.setHeader('Content-type', 'application/json');

        // Send Request
        HttpResponse response = (new Http()).send(request);

        if(response != null && (response.getHeader('Content-Type')).contains('json'))
        {
            System.debug('=> Formating for JSON response');
            // Format responseBody string before returning
            String inboundResponseBody = ESignLiveJSONHelper.prepareInboundJSON(response.getBody());
            response.setBody(inboundResponseBody);
        }

        return response;
    }
    
    public String createPackage() {
        //Create esl client
        ESignLiveSDK sdk = new ESignLiveSDK();
         
        //Create package
        ESignLiveAPIObjects.Package_x pkg = new ESignLiveAPIObjects.Package_x();
        pkg.name = 'Test get Signing Url - ' + Datetime.now().format();
         
        String packageId = sdk.createPackage(pkg);
        System.debug('PackageId: ' + packageId);
        
        //Add Signer
        String roleResponse = sdk.addRole('John', 'Smith', 'signer1@mailinator.com', packageId);
         
        //Add Document
        StaticResource sr = [SELECT Id, Body FROM StaticResource WHERE Name = 'testdoc1' LIMIT 1];
        Map<String,Blob> doc = new Map<String,Blob>();
        doc.put('Sample Document', sr.Body);
         
        ESignLiveAPIObjects.Document document = new ESignLiveAPIObjects.Document();
        document.name = 'Sample Contract';
        document.id = 'document1';
         
        sdk.createDocuments(packageId, document, doc);
        

        //Add Signature
        Map<String,Object> role = (Map<String,Object>)JSON.deserializeUntyped(roleResponse);
        String roleId = (String)(role.get('id'));
        System.debug('roleId: '+ roleId);
         
        ESignLiveAPIObjects.Field field = new ESignLiveAPIObjects.Field();
        field.left = 208;
        field.width = 200;
        field.height = 50;
        field.top = 518;
        field.page = 0;
        field.subtype = 'FULLNAME';
        field.type = 'SIGNATURE';
         
        List<ESignLiveAPIObjects.Field> fields = new List<ESignLiveAPIObjects.Field>();
        fields.add(field);
         
        ESignLiveAPIObjects.Approval approval = new ESignLiveAPIObjects.Approval();
        approval.fields = fields;
        approval.role = roleId;
         
        String signatureResponse = sdk.addSignature(packageId, 'document1', approval);
         
        //Send package
        pkg.status = ESignLiveAPIObjects.PackageStatus.SENT;
         
        sdk.updatePackage(pkg, packageId);  
        
        return packageId;   
    }
    
}